Module: Test::Unit::Notify
- Defined in:
- lib/test/unit/notify.rb
Defined Under Namespace
Classes: Notifier
Constant Summary collapse
- VERSION =
test-unit-notify version number formatted as “#{MAJOR}.#{MINOR}.#{MICRO}”.
"1.0.0"- @@enable =
nil
Class Method Summary collapse
-
.disable ⇒ Object
Disables test result notification by default.
-
.enable ⇒ Object
Enables test result notification by default.
-
.enable=(enable) ⇒ Object
deprecated
Deprecated.
Use Notify.enable or Notify.disable instead.
-
.enabled? ⇒ Boolean
Return whether test result notification is enabled or not.
Class Method Details
.disable ⇒ Object
Disables test result notification by default. It
can be disabled by --notify command line option.
51 52 53 |
# File 'lib/test/unit/notify.rb', line 51 def disable @@enable = false end |
.enable ⇒ Object
Enables test result notification by default. It
can be disabled by --no-notify command line
option.
45 46 47 |
# File 'lib/test/unit/notify.rb', line 45 def enable @@enable = true end |
.enable=(enable) ⇒ Object
56 57 58 |
# File 'lib/test/unit/notify.rb', line 56 def enable=(enable) self.default = enable end |
.enabled? ⇒ Boolean
Return whether test result notification is enabled or not.
62 63 64 65 |
# File 'lib/test/unit/notify.rb', line 62 def enabled? @@enable = Notifier.available? if @@enable.nil? @@enable end |